@@ -339,7 +339,7 @@ squeezing in the frequency domain, then using the inverse DFT to get the time do
 	      (data1 (make-float-vector (+ len 1))))
 	  (copy data data1 1)
 	  (float-vector-abs! (float-vector-multiply! data1 data))
-	  (float-vector-multiply! data (make-shared-vector data1 (list len) 1))
+	  (float-vector-multiply! data (subvector data1 len 1))
 	  (let ((amp1 (/ amp (float-vector-peak data))))
 	    (float-vector->channel (float-vector-scale! data amp1) 0 len snd chn current-edit-position "spike")))))))
 
@@ -1543,11 +1543,11 @@ shift the given channel in pitch without changing its length.  The higher 'order
 	  (set! *output* summer)
 	  (do ((i 0 (+ i 1)))
 	      ((= i pairs))
-	    (do ((gen (vector-ref ssbs i))
-		 (filt (vector-ref bands i))
-		 (k 0 (+ k 1)))
-		((= k len))
-	      (outa k (ssb-am gen (bandpass filt (ina k data)))))) ; outa adds, (ina i v) is the same as (float-vector-ref v i)
+	    (let ((gen (vector-ref ssbs i))
+		  (filt (vector-ref bands i)))
+	      (do ((k 0 (+ k 1)))
+		  ((= k len))
+		(outa k (ssb-am gen (bandpass filt (ina k data))))))) ; outa adds, (ina i v) is the same as (float-vector-ref v i)
 	  (set! *output* #f)
 	  (float-vector-scale! summer (/ mx (float-vector-peak summer)))
 	  (float-vector->channel summer beg len snd chn current-edit-position
@@ -1581,12 +1581,12 @@ shift the given channel in pitch without changing its length.  The higher 'order
 	  (set! *output* summer)
 	  (do ((i 0 (+ i 1)))
 	      ((= i pairs))
-	    (do ((gen (vector-ref ssbs i))
-		 (filt (vector-ref bands i))
-		 (e (vector-ref frenvs i))
-		 (k 0 (+ k 1)))
-		((= k len))
-	      (outa k (ssb-am gen (bandpass filt (ina k data)) (env e)))))
+	    (let ((gen (vector-ref ssbs i))
+		  (filt (vector-ref bands i))
+		  (e (vector-ref frenvs i)))
+	      (do ((k 0 (+ k 1)))
+		  ((= k len))
+		(outa k (ssb-am gen (bandpass filt (ina k data)) (env e))))))
 	  (set! *output* #f)
 	  (float-vector-scale! summer (/ mx (float-vector-peak summer)))
 	  (float-vector->channel summer beg len snd chn current-edit-position
